@@ -20,7 +20,6 @@
  *
  * ============================================================ */
 
-#include "batchprocessimagesdialog.h"
 #include "batchprocessimagesdialog.moc"
 
 // C ANSI includes
@@ -68,6 +67,8 @@ extern "C"
 #include "pluginsversion.h"
 #include "ui_batchprocessimagesdialog.h"
 
+using namespace KIPIPlugins;
+
 namespace KIPIBatchProcessImagesPlugin
 {
 
@@ -619,9 +620,9 @@ void BatchProcessImagesDialog::slotFinished()
 
             if (src != dest)
             {
-                KIPI::ImageInfo srcInfo = m_interface->info(src);
+                KIPI::ImageInfo srcInfo  = m_interface->info(src);
                 KIPI::ImageInfo destInfo = m_interface->info(dest);
-                destInfo.cloneData(srcInfo);
+                srcInfo.cloneData(destInfo);
             }
 
             if (m_ui->m_removeOriginal->isChecked() && src != dest)
