@@ -6,13 +6,13 @@
 // accordance with the terms of the Adobe license agreement accompanying it.
 /*****************************************************************************/
 
-/* $Id: //mondo/dng_sdk_1_2/dng_sdk/source/dng_flags.h#2 $ */ 
-/* $DateTime: 2008/04/02 14:06:57 $ */
-/* $Change: 440485 $ */
+/* $Id: //mondo/dng_sdk_1_3/dng_sdk/source/dng_flags.h#1 $ */ 
+/* $DateTime: 2009/06/22 05:04:49 $ */
+/* $Change: 578634 $ */
 /* $Author: tknoll $ */
 
 /** \file
- * Connditional compilation flags for DNG SDK.
+ * Conditional compilation flags for DNG SDK.
  *
  * All conditional compilation macros for the DNG SDK begin with a lowercase 'q'.
  */
@@ -70,18 +70,6 @@
 #if defined(qDNGLittleEndian)
 #define qDNGBigEndian !qDNGLittleEndian
 
-#elif defined(__hppa__)
-#define qDNGBigEndian 1
-
-#elif defined(__sparc__)
-#define qDNGBigEndian 1
-
-#elif defined(__s390x__)
-#define qDNGBigEndian 1
-
-#elif defined(__s390__)
-#define qDNGBigEndian 1
-
 #elif defined(__POWERPC__)
 #define qDNGBigEndian 1
 
