@@ -50,7 +50,7 @@ K_EXPORT_PLUGIN ( FlashExportFactory("kipiplugin_flashexport") )
 Plugin_FlashExport::Plugin_FlashExport(QObject *parent, const QVariantList&)
                    : KIPI::Plugin(FlashExportFactory::componentData(), parent, "FlashExport")
 {
-    kDebug(51001) << "Plugin_FlashExport plugin loaded" ;
+    kDebug(AREA_CODE_LOADING) << "Plugin_FlashExport plugin loaded" ;
 }
 
 void Plugin_FlashExport::setup(QWidget* widget)
@@ -62,7 +62,7 @@ void Plugin_FlashExport::setup(QWidget* widget)
     m_actionFlashExport = actionCollection()->addAction("flashexport");
     m_actionFlashExport->setText(i18n("Export to F&lash..."));
     m_actionFlashExport->setIcon(KIcon("flash"));
-    m_actionFlashExport->setShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_L);
+    m_actionFlashExport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_L));
 
     connect(m_actionFlashExport, SIGNAL(triggered(bool)),
             this, SLOT(slotActivate()));
@@ -72,7 +72,7 @@ void Plugin_FlashExport::setup(QWidget* widget)
     m_interface = dynamic_cast< KIPI::Interface* >( parent() );
     if ( !m_interface )
     {
-        kError( 51000 ) << "Kipi interface is null!" ;
+        kError() << "Kipi interface is null!" ;
         return;
     }
 }
@@ -82,7 +82,7 @@ KIPI::Category Plugin_FlashExport::category( KAction* action ) const
     if ( action == m_actionFlashExport )
        return KIPI::ExportPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification" ;
+    kWarning() << "Unrecognized action for plugin category identification" ;
     return KIPI::ExportPlugin; // no warning from compiler, please
 }
 
@@ -90,7 +90,7 @@ void Plugin_FlashExport::slotActivate()
 {
     if ( !m_interface )
     {
-        kError( 51000 ) << "Kipi interface is null!" ;
+        kError() << "Kipi interface is null!" ;
         return;
     }
 
