@@ -65,10 +65,6 @@
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
-
 // Local includes
 
 #include "pluginsversion.h"
@@ -392,7 +388,7 @@ void FlickrTalker::getPhotoProperty(const QString& method, const QStringList& ar
 
     for (QStringList::const_iterator it = argList.constBegin(); it != argList.constEnd(); ++it)
     {
-        QStringList str = (*it).split("=", QString::SkipEmptyParts);
+        QStringList str = (*it).split('=', QString::SkipEmptyParts);
         url.addQueryItem(str[0], str[1]);
     }
 
@@ -497,7 +493,7 @@ void FlickrTalker::addPhotoToPhotoSet(const QString& photoId,
      * it doesn't exist yet on Flickr and needs to be created. Note that it's
      * not necessary to subsequently add the photo to the photo set, as this
      * is done in the set creation call to Flickr. */
-    if (photoSetId.startsWith("UNDEFINED_"))
+    if (photoSetId.startsWith(QLatin1String("UNDEFINED_")))
     {
         createPhotoSet("", m_selectedPhotoSet.title, m_selectedPhotoSet.description, photoId);
     }
@@ -600,11 +596,7 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
     QImage image;
 
     // Check if RAW file.
-#if KDCRAW_VERSION < 0x000400
-    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
     QFileInfo fileInfo(photoPath);
     if (rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper()))
         KDcrawIface::KDcraw::loadDcrawPreview(image, photoPath);
