@@ -7,7 +7,7 @@
  * Description : a kipi plugin to export images to Flickr web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -43,6 +43,7 @@ extern "C"
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <kactioncollection.h>
+#include <kwindowsystem.h>
 
 // LibKIPI includes
 
@@ -58,11 +59,15 @@ K_EXPORT_PLUGIN ( FlickrExportFactory("kipiplugin_flickrexport") )
 Plugin_FlickrExport::Plugin_FlickrExport(QObject *parent, const QVariantList &/*args*/)
                    : KIPI::Plugin(FlickrExportFactory::componentData(), parent, "FlickrExport")
 {
-    kDebug(51001) << "Plugin_FlickrExport plugin loaded";
+    kDebug(AREA_CODE_LOADING) << "Plugin_FlickrExport plugin loaded";
 }
 
 void Plugin_FlickrExport::setup(QWidget* widget)
 {
+    m_dlgFlickr = 0;
+    m_dlg23     = 0;
+    m_dlgZooomr = 0;
+
     KIPI::Plugin::setup(widget);
 
     KIconLoader::global()->addAppDir("kipiplugin_flickrexport");
@@ -71,10 +76,10 @@ void Plugin_FlickrExport::setup(QWidget* widget)
     m_actionFlickr->setText(i18n("Export to Flick&r..."));
     m_actionFlickr->setIcon(KIcon("flickr"));
     m_actionFlickr->setEnabled(false);
-    m_actionFlickr->setShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_R);
+    m_actionFlickr->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_R));
 
     connect(m_actionFlickr, SIGNAL(triggered(bool)),
-            this, SLOT(slotActivate()));
+            this, SLOT(slotActivateFlickr()));
 
     addAction(m_actionFlickr);
 
@@ -82,7 +87,7 @@ void Plugin_FlickrExport::setup(QWidget* widget)
     m_action23->setText(i18n("Export to &23..."));
     m_action23->setIcon(KIcon("hq"));
     m_action23->setEnabled(false);
-    m_action23->setShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_2);
+    m_action23->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_2));
 
     connect(m_action23, SIGNAL(triggered(bool)),
             this, SLOT(slotActivate23()));
@@ -93,7 +98,7 @@ void Plugin_FlickrExport::setup(QWidget* widget)
     m_actionZooomr->setText(i18n("Export to &Zooomr..."));
     m_actionZooomr->setIcon(KIcon("zooomr"));
     m_actionZooomr->setEnabled(false);
-    m_actionZooomr->setShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_Z);
+    m_actionZooomr->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_Z));
 
     connect(m_actionZooomr, SIGNAL(triggered(bool)),
             this, SLOT(slotActivateZooomr()));
@@ -104,7 +109,7 @@ void Plugin_FlickrExport::setup(QWidget* widget)
 
     if (!interface)
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
     m_actionFlickr->setEnabled(true);
@@ -116,21 +121,32 @@ Plugin_FlickrExport::~Plugin_FlickrExport()
 {
 }
 
-void Plugin_FlickrExport::slotActivate()
+void Plugin_FlickrExport::slotActivateFlickr()
 {
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     KStandardDirs dir;
-    QString tmp = dir.saveLocation("tmp", "kipi-flickrexportplugin-" + QString::number(getpid()) + "/");
+    QString tmp = dir.saveLocation("tmp", QString("kipi-flickrexportplugin-") + QString::number(getpid()) + QString("/"));
 
-    // We clean it up in the close button
-    m_dlg = new KIPIFlickrExportPlugin::FlickrWindow(interface, tmp, kapp->activeWindow(), "Flickr");
-    m_dlg->show();
+    if (!m_dlgFlickr)
+    {
+        // We clean it up in the close button
+        m_dlgFlickr = new KIPIFlickrExportPlugin::FlickrWindow(interface, tmp, kapp->activeWindow(), "Flickr");
+    }
+    else
+    {
+        if (m_dlgFlickr->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlgFlickr->winId());
+
+        KWindowSystem::activateWindow(m_dlgFlickr->winId());
+    }
+
+    m_dlgFlickr->reactivate();
 }
 
 void Plugin_FlickrExport::slotActivate23()
@@ -138,16 +154,27 @@ void Plugin_FlickrExport::slotActivate23()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     KStandardDirs dir;
-    QString tmp = dir.saveLocation("tmp", "kipi-23exportplugin-" + QString::number(getpid()) + "/");
+    QString tmp = dir.saveLocation("tmp", QString("kipi-23exportplugin-") + QString::number(getpid()) + QString("/"));
 
-    // We clean it up in the close button
-    m_dlg = new KIPIFlickrExportPlugin::FlickrWindow(interface, tmp, kapp->activeWindow(), "23");
-    m_dlg->show();
+    if (!m_dlg23)
+    {
+        // We clean it up in the close button
+        m_dlg23 = new KIPIFlickrExportPlugin::FlickrWindow(interface, tmp, kapp->activeWindow(), "23");
+    }
+    else
+    {
+        if (m_dlg23->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlg23->winId());
+
+        KWindowSystem::activateWindow(m_dlg23->winId());
+    }
+
+    m_dlg23->reactivate();
 }
 
 void Plugin_FlickrExport::slotActivateZooomr()
@@ -155,16 +182,27 @@ void Plugin_FlickrExport::slotActivateZooomr()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     KStandardDirs dir;
-    QString tmp = dir.saveLocation("tmp", "kipi-Zooomrexportplugin-" + QString::number(getpid()) + "/");
+    QString tmp = dir.saveLocation("tmp", QString("kipi-Zooomrexportplugin-") + QString::number(getpid()) + QString("/"));
 
-    // We clean it up in the close button
-    m_dlg = new KIPIFlickrExportPlugin::FlickrWindow(interface, tmp, kapp->activeWindow(), "Zooomr");
-    m_dlg->show();
+    if (!m_dlgZooomr)
+    {
+        // We clean it up in the close button
+        m_dlgZooomr = new KIPIFlickrExportPlugin::FlickrWindow(interface, tmp, kapp->activeWindow(), "Zooomr");
+    }
+    else
+    {
+        if (m_dlgZooomr->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlgZooomr->winId());
+
+        KWindowSystem::activateWindow(m_dlgZooomr->winId());
+    }
+
+    m_dlgZooomr->reactivate();
 }
 
 KIPI::Category Plugin_FlickrExport::category( KAction* action ) const
@@ -172,6 +210,6 @@ KIPI::Category Plugin_FlickrExport::category( KAction* action ) const
     if (action == m_actionFlickr || action == m_action23 || action == m_actionZooomr)
         return KIPI::ExportPlugin;
 
-    kWarning(51000) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::ExportPlugin;
 }
