@@ -201,7 +201,7 @@ GPSSyncDialog::GPSSyncDialog(KIPI::Interface* interface, QWidget* parent)
                     "Use this option if the timezone of the camera "
                     "is the same as the timezone of this system. "
                     "The conversion to GMT will be done automatically."));
-    d->timeZoneManual     = new QRadioButton(i18n("Manual:"), settingsBox);
+    d->timeZoneManual     = new QRadioButton(i18nc("manual time zone selection for gps syncing", "Manual:"), settingsBox);
     d->timeZoneManual->setWhatsThis(i18n(
                     "Use this option if the timezone of the camera "
                     "is different from this system and you have to "
@@ -510,6 +510,7 @@ void GPSSyncDialog::readSettings()
     d->offsetSign->setCurrentIndex(group.readEntry("Offset Sign", 0));
     d->offsetMin->setValue(group.readEntry("Offset Min", 0));
     d->offsetSec->setValue(group.readEntry("Offset Sec", 0));
+    d->gpxFileOpenLastDirectory = group.readEntry("GPX File Open Last Directory", KGlobalSettings::documentPath());
 
     d->maxTimeLabel->setEnabled(d->interpolateBox->isChecked());
     d->maxTimeInput->setEnabled(d->interpolateBox->isChecked());
@@ -530,6 +531,7 @@ void GPSSyncDialog::saveSettings()
     group.writeEntry("Offset Sign", d->offsetSign->currentIndex());
     group.writeEntry("Offset Min", d->offsetMin->value());
     group.writeEntry("Offset Sec", d->offsetSec->value());
+    group.writeEntry("GPX File Open Last Directory", d->gpxFileOpenLastDirectory);
 
     KConfigGroup group2 = config.group(QString("GPS Sync Dialog"));
     saveDialogSize(group2);
