@@ -6,8 +6,8 @@
  * Date        : 2003-10-14
  * Description : batch image flip
  *
- * Copyright (C) 2004-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2003-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2003-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,6 +42,7 @@ extern "C"
 
 #include <QFile>
 #include <QFileInfo>
+#include <QFSFileEngine>
 
 // KDE includes
 
@@ -87,6 +88,11 @@ bool ImageFlip::flip(const QString& src, FlipAction action, QString& err, bool u
 
     QString tmp = m_tmpFile.fileName();
 
+//Workaround to close the file
+#ifdef _WIN32
+    static_cast<QFSFileEngine*>(m_tmpFile.fileEngine())->rename(tmp);
+#endif
+
     if (Utils::isRAW(src))
     {
         err = i18n("Cannot rotate RAW file");
