@@ -7,7 +7,7 @@
  * Description : a kipi plugin to export images to Picasa web service
  *
  * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,7 +21,6 @@
  *
  * ============================================================ */
 
-#include "plugin_picasawebexport.h"
 #include "plugin_picasawebexport.moc"
 
 // C ANSI includes
@@ -55,17 +54,18 @@ extern "C"
 K_PLUGIN_FACTORY( PicasawebExportFactory, registerPlugin<Plugin_PicasawebExport>(); )
 K_EXPORT_PLUGIN ( PicasawebExportFactory("kipiplugin_picasawebexport") )
 
-Plugin_PicasawebExport::Plugin_PicasawebExport(QObject *parent, const QVariantList&)
-                      : KIPI::Plugin(PicasawebExportFactory::componentData(), parent, "PicasawebExport")
+Plugin_PicasawebExport::Plugin_PicasawebExport(QObject* parent, const QVariantList&)
+                      : Plugin(PicasawebExportFactory::componentData(), parent, "PicasawebExport")
 {
     m_dlgExport = 0;
+    m_dlgImport = 0;
 
     kDebug(AREA_CODE_LOADING) << "Plugin_PicasawebExport plugin loaded" ;
 }
 
 void Plugin_PicasawebExport::setup(QWidget* widget)
 {
-    KIPI::Plugin::setup(widget);
+    Plugin::setup(widget);
 
     KIconLoader::global()->addAppDir("kipiplugin_picasawebexport");
 
@@ -75,19 +75,30 @@ void Plugin_PicasawebExport::setup(QWidget* widget)
     m_actionExport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_P));
 
     connect(m_actionExport, SIGNAL(triggered(bool)),
-            this, SLOT(slotActivate()));
+            this, SLOT(slotExport()));
 
     addAction(m_actionExport);
 
-    KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
+    m_actionImport = actionCollection()->addAction("picasawebimport");
+    m_actionImport->setText(i18n("Import from &PicasaWeb..."));
+    m_actionImport->setIcon(KIcon("picasa"));
+    m_actionImport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::CTRL+Qt::Key_P));
 
+    connect(m_actionImport, SIGNAL( triggered(bool) ),
+            this, SLOT( slotImport()) );
+
+    addAction(m_actionImport);
+
+    Interface* interface = dynamic_cast<Interface*>(parent());
     if (!interface)
     {
-        kError() << "Kipi interface is null!" ;
+        kError() << "Kipi interface is null!";
+        m_actionImport->setEnabled(false);
         m_actionExport->setEnabled(false);
         return;
     }
 
+    m_actionImport->setEnabled(true);
     m_actionExport->setEnabled(true);
 }
 
@@ -95,9 +106,9 @@ Plugin_PicasawebExport::~Plugin_PicasawebExport()
 {
 }
 
-void Plugin_PicasawebExport::slotActivate()
+void Plugin_PicasawebExport::slotExport()
 {
-    KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
+    Interface* interface = dynamic_cast<Interface*>(parent());
     if (!interface)
     {
         kError() << "Kipi interface is null!" ;
@@ -110,7 +121,7 @@ void Plugin_PicasawebExport::slotActivate()
     if (!m_dlgExport)
     {
         // We clean it up in the close button
-        m_dlgExport = new KIPIPicasawebExportPlugin::PicasawebWindow(interface, Tmp, kapp->activeWindow());
+        m_dlgExport = new KIPIPicasawebExportPlugin::PicasawebWindow(interface, Tmp, false, kapp->activeWindow());
     }
     else
     {
@@ -120,14 +131,44 @@ void Plugin_PicasawebExport::slotActivate()
         KWindowSystem::activateWindow(m_dlgExport->winId());
     }
 
-    m_dlgExport->show();
+    m_dlgExport->reactivate();
 }
 
-KIPI::Category Plugin_PicasawebExport::category( KAction* action ) const
+void Plugin_PicasawebExport::slotImport()
+{
+    Interface* interface = dynamic_cast<Interface*>(parent());
+    if (!interface)
+    {
+        kError() << "Kipi interface is null!";
+        return;
+    }
+
+    KStandardDirs dir;
+    QString tmp = dir.saveLocation("tmp", QString("kipi-picasawebexportplugin-") + QString::number(getpid()) + QString("/"));
+
+    if (!m_dlgImport)
+    {
+        // We clean it up in the close button
+        m_dlgImport = new KIPIPicasawebExportPlugin::PicasawebWindow(interface, tmp, true, kapp->activeWindow());
+    }
+    else
+    {
+        if (m_dlgImport->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlgImport->winId());
+
+        KWindowSystem::activateWindow(m_dlgImport->winId());
+    }
+
+    m_dlgImport->show();
+}
+
+Category Plugin_PicasawebExport::category( KAction* action ) const
 {
     if (action == m_actionExport)
-        return KIPI::ExportPlugin;
+        return ExportPlugin;
+    else if (action == m_actionImport)
+        return ImportPlugin;
 
     kWarning() << "Unrecognized action for plugin category identification" ;
-    return KIPI::ExportPlugin;
+    return ExportPlugin;
 }
