@@ -25,14 +25,17 @@
 #define SMUGTALKER_H
 
 // Qt includes
+
 #include <QList>
 #include <QString>
 #include <QObject>
 
 // KDE includes
+
 #include <KIO/Job>
 
 // local includes
+
 #include "smugitem.h"
 
 namespace KIPISmugPlugin
@@ -43,6 +46,7 @@ class SmugTalker : public QObject
     Q_OBJECT
 
 public:
+
     SmugTalker(QWidget* parent);
     ~SmugTalker();
 
@@ -63,10 +67,12 @@ public:
 
     void    createAlbum(const SmugAlbum& album);
 
-    bool    addPhoto(const QString& imgPath, int albumID);
+    bool    addPhoto(const QString& imgPath, int albumID, 
+                     const QString& caption);
     void    getPhoto(const QString& imgPath);
 
-signals:
+Q_SIGNALS:
+
     void signalBusy(bool val);
     void signalLoginProgress(int step, int maxStep = 0, 
                              const QString& label = "");
@@ -88,6 +94,27 @@ signals:
                                      const QList <SmugCategory>& categoriesList);
 
 private:
+
+
+    QString htmlToText(const QString& htmlText);
+    QString errorToText(int errCode, const QString& errMsg);
+    void parseResponseLogin(const QByteArray& data);
+    void parseResponseLogout(const QByteArray& data);
+    void parseResponseAddPhoto(const QByteArray& data);
+    void parseResponseCreateAlbum(const QByteArray& data);
+    void parseResponseListAlbums(const QByteArray& data);
+    void parseResponseListPhotos(const QByteArray& data);
+    void parseResponseListAlbumTmpl(const QByteArray& data);
+    void parseResponseListCategories(const QByteArray& data);
+    void parseResponseListSubCategories(const QByteArray& data);
+
+private Q_SLOTS:
+
+    void data(KIO::Job *job, const QByteArray& data);
+    void slotResult(KJob *job);
+
+private:
+
     enum State
     {
         SMUG_LOGIN = 0,
@@ -102,23 +129,6 @@ private:
         SMUG_GETPHOTO
     };
 
-    QString htmlToText(const QString& htmlText);
-    QString errorToText(int errCode, const QString& errMsg);
-    void parseResponseLogin(const QByteArray& data);
-    void parseResponseLogout(const QByteArray& data);
-    void parseResponseAddPhoto(const QByteArray& data);
-    void parseResponseCreateAlbum(const QByteArray& data);
-    void parseResponseListAlbums(const QByteArray& data);
-    void parseResponseListPhotos(const QByteArray& data);
-    void parseResponseListAlbumTmpl(const QByteArray& data);
-    void parseResponseListCategories(const QByteArray& data);
-    void parseResponseListSubCategories(const QByteArray& data);
-
-private slots:
-    void data(KIO::Job *job, const QByteArray& data);
-    void slotResult(KJob *job);
-
-private:
     QWidget*   m_parent;
 
     QByteArray m_buffer;
